@@ -8,6 +8,7 @@
 #' @param object a \code{lvm} object.
 #' @param data [optional] a dataset used to identify the categorical variables when not specified in the \code{lvm} object.
 #' @param exclude.var [character vector] all links related to these variables will be ignore.
+#' @param type [character vector] the type of links to be considered: \code{"regression"}, \code{"covariance"}, or \code{"both"}, .
 #' @param rm.latent_latent [logical] should the links relating two latent variables be ignored?
 #' @param rm.endo_endo [logical] should the links relating two endogenous variables be ignored?
 #' @param rm.latent_endo [logical] should the links relating one endogenous variable and one latent variable be ignored?
@@ -39,6 +40,8 @@
 #' findNewLink(m, rm.endo = FALSE)
 #' findNewLink(m, rm.endo = TRUE)
 #' findNewLink(m, rm.endo = TRUE, output = "index")
+#' findNewLink(m, type = "covariance")
+#' findNewLink(m, type = "regression")
 #' 
 #' @concept modelsearch
 #' @export
@@ -48,15 +51,22 @@
 ## ** method findNewLink.lvm
 #' @export
 #' @rdname findNewLink
-findNewLink.lvm <- function(object, data = NULL,
-                            exclude.var = NULL, rm.latent_latent= FALSE, rm.endo_endo= FALSE, rm.latent_endo= FALSE,
-                            output = "names", ...){
+findNewLink.lvm <- function(object,                            
+                            data = NULL,
+                            type = "both",
+                            exclude.var = NULL,
+                            rm.latent_latent= FALSE,
+                            rm.endo_endo= FALSE,
+                            rm.latent_endo= FALSE,
+                            output = "names",
+                            ...){
 
     match.arg(output, choices = c("names","index"))
+    match.arg(type, choices = c("both","covariance","regression"))
     if(is.null(data)){        
         data <- lava::sim(object, n = 1)
     }
-   
+    
     ## *** convertion to dummy variable name for categorical variables
     xF <- lava_categorical2dummy(object, data)
     AP <- with(lava::index(xF$x), A + t(A) + P)
@@ -82,7 +92,7 @@ findNewLink.lvm <- function(object, data = NULL,
 
             var.i <- rownames(AP)[i]
             var.j <- rownames(AP)[j]
-          
+            
             if(!is.null(exclude.var) && (var.i %in% exclude.var || var.j %in% exclude.var)){
                 next
             }
@@ -106,14 +116,20 @@ findNewLink.lvm <- function(object, data = NULL,
             if(rm.latent_endo && ( (isLatent.i && isEndogenous.j) || (isEndogenous.i && isLatent.j) )){
                 next
             }
-      
+            iDirectional <- (isExogenous.i+isExogenous.j)>0
+            if(type == "regression" && iDirectional == FALSE){
+                next
+            }
+            if(type == "covariance" && iDirectional == TRUE){
+                next
+            }
+            
             if (AP[j, i] == 0){
                 restricted <- rbind(restricted, c(i, j))
-                directional <- c(directional, (isExogenous.i+isExogenous.j)>0 )
+                directional <- c(directional, iDirectional)
             }
         }
     }
-
     ## *** export  
     out <- list(M.links = restricted,
                 links = NULL,
@@ -127,7 +143,7 @@ findNewLink.lvm <- function(object, data = NULL,
             out$M.links <- M.names
         }
     }
-   
+    
     return(out)  
 }
 
@@ -181,7 +197,7 @@ addLink.lvm <- function(object,
                         var1,
                         var2,
                         covariance,
-                        all.vars = vars(object),
+                        all.vars = lava::vars(object),
                         warnings = FALSE,
                         ...){
 
@@ -253,7 +269,7 @@ addLink.lvm <- function(object,
 ## ** method addLink.lvm.reduced
 #' @rdname addLink
 addLink.lvm.reduced <- function(object, ...){
-  return(addLink.lvm(object, all.vars = vars(object, lp = FALSE, xlp = TRUE) , ...))
+  return(addLink.lvm(object, all.vars = lava::vars(object, lp = FALSE, xlp = TRUE) , ...))
 }
 
 ## * setLink
